@@ -2,6 +2,5 @@
 //! as there exist 2^N children per node, where N is the number of dimensions.
 //! A quadtree is the two-dimensional case, an octtree is the three-dimensional case of the tpntree.
 
-mod tpntree;
-
-pub use crate::tpntree::TpnTree;
+pub mod tpntree;
+pub mod tpntree_dynamic;
